==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/TrafficWeightArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.TrafficWeightArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Traffic weight assigned to a revision
 * @property label Associates a traffic label with a revision
 * @property latestRevision Indicates that the traffic weight belongs to a latest stable revision
 * @property revisionName Name of a revision
 * @property weight Traffic weight assigned to a revision
 */
public data class TrafficWeightArgs(
    public val label: Output<String>? = null,
    public val latestRevision: Output<Boolean>? = null,
    public val revisionName: Output<String>? = null,
    public val weight: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.TrafficWeightArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.TrafficWeightArgs =
        com.pulumi.azurenative.app.inputs.TrafficWeightArgs.builder()
            .label(label?.applyValue({ args0 -> args0 }))
            .latestRevision(latestRevision?.applyValue({ args0 -> args0 }))
            .revisionName(revisionName?.applyValue({ args0 -> args0 }))
            .weight(weight?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TrafficWeightArgs].
 */
@PulumiTagMarker
public class TrafficWeightArgsBuilder internal constructor() {
    private var label: Output<String>? = null

    private var latestRevision: Output<Boolean>? = null

    private var revisionName: Output<String>? = null

    private var weight: Output<Int>? = null

    /**
     * @param value Associates a traffic label with a revision
     */
    @JvmName("vhwoodrktinvktrd")
    public suspend fun label(`value`: Output<String>) {
        this.label = value
    }

    /**
     * @param value Indicates that the traffic weight belongs to a latest stable revision
     */
    @JvmName("ngkvxhhabmedgcop")
    public suspend fun latestRevision(`value`: Output<Boolean>) {
        this.latestRevision = value
    }

    /**
     * @param value Name of a revision
     */
    @JvmName("scmwpojqwtrgcnvn")
    public suspend fun revisionName(`value`: Output<String>) {
        this.revisionName = value
    }

    /**
     * @param value Traffic weight assigned to a revision
     */
    @JvmName("hwuywaqtliseldgb")
    public suspend fun weight(`value`: Output<Int>) {
        this.weight = value
    }

    /**
     * @param value Associates a traffic label with a revision
     */
    @JvmName("ljuvvpkottowcggd")
    public suspend fun label(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.label = mapped
    }

    /**
     * @param value Indicates that the traffic weight belongs to a latest stable revision
     */
    @JvmName("ooplducbeqkiiqna")
    public suspend fun latestRevision(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.latestRevision = mapped
    }

    /**
     * @param value Name of a revision
     */
    @JvmName("wmltfnaidotxspbp")
    public suspend fun revisionName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.revisionName = mapped
    }

    /**
     * @param value Traffic weight assigned to a revision
     */
    @JvmName("usffwlvgxpgjfejg")
    public suspend fun weight(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weight = mapped
    }

    internal fun build(): TrafficWeightArgs = TrafficWeightArgs(
        label = label,
        latestRevision = latestRevision,
        revisionName = revisionName,
        weight = weight,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/TrafficWeightArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.TrafficWeightArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Traffic weight assigned to a revision
 * @property label Associates a traffic label with a revision
 * @property latestRevision Indicates that the traffic weight belongs to a latest stable revision
 * @property revisionName Name of a revision
 * @property weight Traffic weight assigned to a revision
 */
public data class TrafficWeightArgs(
    public val label: Output<String>? = null,
    public val latestRevision: Output<Boolean>? = null,
    public val revisionName: Output<String>? = null,
    public val weight: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.TrafficWeightArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.TrafficWeightArgs =
        com.pulumi.azurenative.app.inputs.TrafficWeightArgs.builder()
            .label(label?.applyValue({ args0 -> args0 }))
            .latestRevision(latestRevision?.applyValue({ args0 -> args0 }))
            .revisionName(revisionName?.applyValue({ args0 -> args0 }))
            .weight(weight?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TrafficWeightArgs].
 */
@PulumiTagMarker
public class TrafficWeightArgsBuilder internal constructor() {
    private var label: Output<String>? = null

    private var latestRevision: Output<Boolean>? = null

    private var revisionName: Output<String>? = null

    private var weight: Output<Int>? = null

    /**
     * @param value Associates a traffic label with a revision
     */
    @JvmName("hhmsvhqaioypubea")
    public suspend fun label(`value`: Output<String>) {
        this.label = value
    }

    /**
     * @param value Indicates that the traffic weight belongs to a latest stable revision
     */
    @JvmName("bufvyprukrauodju")
    public suspend fun latestRevision(`value`: Output<Boolean>) {
        this.latestRevision = value
    }

    /**
     * @param value Name of a revision
     */
    @JvmName("upenautmlpdeqjti")
    public suspend fun revisionName(`value`: Output<String>) {
        this.revisionName = value
    }

    /**
     * @param value Traffic weight assigned to a revision
     */
    @JvmName("ebiigdkahvwapluc")
    public suspend fun weight(`value`: Output<Int>) {
        this.weight = value
    }

    /**
     * @param value Associates a traffic label with a revision
     */
    @JvmName("xaxbyllmkawtdjcl")
    public suspend fun label(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.label = mapped
    }

    /**
     * @param value Indicates that the traffic weight belongs to a latest stable revision
     */
    @JvmName("pejoebhkfsionvvg")
    public suspend fun latestRevision(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.latestRevision = mapped
    }

    /**
     * @param value Name of a revision
     */
    @JvmName("ipkksgdktvwbccxm")
    public suspend fun revisionName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.revisionName = mapped
    }

    /**
     * @param value Traffic weight assigned to a revision
     */
    @JvmName("ujblodkkycbccmcr")
    public suspend fun weight(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weight = mapped
    }

    internal fun build(): TrafficWeightArgs = TrafficWeightArgs(
        label = label,
        latestRevision = latestRevision,
        revisionName = revisionName,
        weight = weight,
    )
}
